#[non_exhaustive]pub enum ProcessingState {
Unspecified,
Pending,
Running,
Succeeded,
Failed,
UnknownValue(UnknownValue),
}Expand description
The current state of the job.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
The processing state is not specified.
Pending
The job is enqueued and will be picked up for processing soon.
Running
The job is being processed.
Succeeded
The job has been completed successfully.
Failed
The job has failed. For additional information, see Troubleshooting.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ProcessingState::value or ProcessingState::name.
Implementations